@@ -52,7 +52,7 @@ class quantum_lab():
 
         response = requests.post(f"{url_path}", headers=headers, data=body) 
         if response.status_code != 200:
-            return error_handler(response)
+            return self.error_handler(response)
         
         data = response.json()
         
@@ -103,7 +103,7 @@ class quantum_lab():
 
         response = requests.post(f"{url_path}", headers=headers, data=body) 
         if response.status_code != 200:
-            return error_handler(response)
+            return self.error_handler(response)
         
         data = response.json()
         
@@ -123,7 +123,7 @@ class quantum_lab():
         response = requests.get(f"{url_path}",headers=headers)
         
         if response.status_code != 200:
-            return error_handler(response)
+            return self.error_handler(response)
         
         data = response.json()
 
@@ -174,7 +174,7 @@ class quantum_lab():
         response = requests.get(f"{url_path}", headers=headers)
         
         if response.status_code != 200:
-            return error_handler(response)
+            return self.error_handler(response)
 
         data = response.json()
         print("{:<5} {:<10} {:<10} {:<12} {:<9} {:<8} {:<5} {:<11} {:<17} {:<30} {:<30}".format(
@@ -219,7 +219,7 @@ class quantum_lab():
         response = requests.delete(f"{url_path}", headers=headers)
 
         if response.status_code != 200:
-            return error_handler(response)
+            return self.error_handler(response)
 
         print(f"Deleted job : {response.text}")
 
